"""DSM 7 SYNO.API.Info data."""

DSM_7_API_INFO = {
    "data": {
        "SYNO.AME.Config": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.AME.License": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.AME.Pack": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.AME.Payment": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.API.Auth": {"maxVersion": 7, "minVersion": 1, "path": "entry.cgi"},
        "SYNO.API.Auth.Key": {
            "maxVersion": 7,
            "minVersion": 7,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.API.Auth.Key.Code": {
            "maxVersion": 7,
            "minVersion": 7,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.API.Auth.RedirectURI": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.API.Auth.Type": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.API.Auth.UIConfig": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.API.Encryption": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.API.Info": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.API.OTP": {"maxVersion": 1, "minVersion": 1, "path": "otp.cgi"},
        "SYNO.ActiveBackup.Activation": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.ActiveBackup.Agent": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.ActiveBackup.Agent.Device": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.ActiveBackup.Agentless": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.ActiveBackup.Delegation": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.ActiveBackup.Device": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.ActiveBackup.Inventory": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.ActiveBackup.Log": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.ActiveBackup.NFSPrivilege": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.ActiveBackup.Overview": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.ActiveBackup.Report": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.ActiveBackup.ReportConfig": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.ActiveBackup.ReportGet": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.ActiveBackup.Restore": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.ActiveBackup.RestoreVM": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.ActiveBackup.Setting": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.ActiveBackup.Share": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.ActiveBackup.Storage": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.ActiveBackup.Task": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.ActiveBackup.TaskTemplate": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.ActiveBackup.UserGroup": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.ActiveBackup.Version": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.ActiveBackup.Wrapper.Domain": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.ActiveBackup.Wrapper.LDAP": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.ActiveBackup.Wrapper.NFS": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.ActiveBackup.Wrapper.NFSPrivilege": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.ActiveInsight.CompleteCollection": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.ActiveInsight.License": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.ActiveInsight.Package": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.ActiveInsight.Setting": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.AddressBook.Contact": {
            "maxVersion": 4,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.AddressBook.ContactGroup": {
            "maxVersion": 4,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.AddressBook.Info": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.AudioPlayer": {
            "maxVersion": 2,
            "minVersion": 2,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.AudioPlayer.Stream": {
            "maxVersion": 2,
            "minVersion": 2,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Auth.ForgotPwd": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Auth.RescueEmail": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Backup.App": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Backup.App.Backup": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Backup.App.Restore": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Backup.App2.Backup": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Backup.App2.Restore": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Backup.Config.AutoBackup": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Backup.Config.Backup": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Backup.Config.Restore": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Backup.Lunbackup": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Backup.Repository": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Backup.Repository.Certificate": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Backup.Repository.LoginPort": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Backup.Restore": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Backup.Service.NetworkBackup": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Backup.Service.VersionBackup.Config": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Backup.Service.VersionBackup.Target": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Backup.Service.VersionBackup.Version": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Backup.Service.VersionBackup.Version.History": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Backup.Share.Restore": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Backup.Source.Folder": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Backup.Storage.AmazonCloudDrive.Container": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Backup.Storage.Azure.Container": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Backup.Storage.Connect.Network": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Backup.Storage.Dropbox.Container": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Backup.Storage.GoogleDrive.Container": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Backup.Storage.HiDrive.Container": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Backup.Storage.OpenStack.Container": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Backup.Storage.OpenStack.Region": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Backup.Storage.S3.Bucket": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Backup.Storage.Share.Local": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Backup.Storage.Share.Network": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Backup.Storage.Share.Rsync": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Backup.Storage.WebDAV.Container": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Backup.Storage.hubiC.Container": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Backup.Target": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Backup.Target.Config": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Backup.Task": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Backup.Version": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Backup.Version.History": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Btrfs.Replica.Core": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.C2FS.Account": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.C2FS.Bucket": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.C2FS.Conf": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.C2FS.File": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.C2FS.Share": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.C2FS.Share.Status": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.C2FS.Snapshot": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.C2FS.Transform": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.C2FS.Utils": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.CCC.CLog": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.CCC.Cluster": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.CCC.Cluster.Member": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.CCC.Guest": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.CCC.Guest.Image": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.CCC.Guest.VNC": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.CCC.GuestReplica": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.CCC.GuestSnap": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.CCC.GuestSnap.Policy": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.CCC.HA": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.CCC.License": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.CCC.License.Pro": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.CCC.License.VDSM": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.CCC.Network": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.CCC.Network.SRIOV": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.CCC.Notify": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.CCC.Package": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.CCC.Repo": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.CCC.Resource": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.CCC.Utils": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.CCC.VDisk": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.CCC.VNic": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Cal.AuthForeign": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Cal.Cal": {
            "maxVersion": 5,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Cal.Chatbot": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Cal.Contact": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Cal.Event": {
            "maxVersion": 5,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Cal.InviteMail": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Cal.InviteMailInit": {
            "maxVersion": 5,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Cal.Proxy": {
            "maxVersion": 5,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Cal.SendMail": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Cal.Setting": {
            "maxVersion": 5,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Cal.Share.Priv": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Cal.Sharing": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Cal.SyncUser": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Cal.Timezone": {
            "maxVersion": 5,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Cal.Todo": {
            "maxVersion": 5,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Cal.UserAction": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Contacts.Addressbook": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Contacts.AdminSetting": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Contacts.Contact": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Contacts.ExternalSource": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Contacts.Info": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Contacts.Label": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Contacts.OU": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.ACL": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.ActionPriv": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.ActionPriv.Role": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.AppNotify": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.AppPortal": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.AppPortal.AccessControl": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.AppPortal.Config": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.AppPortal.ReverseProxy": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.AppPriv": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.AppPriv.App": {
            "maxVersion": 3,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.AppPriv.Rule": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.BackgroundTask": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Backup.ED": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.BandwidthControl": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.BandwidthControl.Protocol": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.BandwidthControl.Status": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.CMS": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.CMS.Cache": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.CMS.Identity": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.CMS.Info": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.CMS.Policy": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.CMS.ServerInfo": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.CMS.Task": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.CMS.Token": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Certificate": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Certificate.CRT": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Certificate.CSR": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Certificate.LetsEncrypt": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Certificate.LetsEncrypt.Account": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Certificate.Service": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Certificate.Tencent": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.CurrentConnection": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.DDNS.Ethernet": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.DDNS.ExtIP": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.DDNS.Provider": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.DDNS.Record": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.DDNS.Synology": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.DDNS.TWNIC": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.DSMNotify": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.DSMNotify.MailContent": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.DSMNotify.Strings": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.DataCollect": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.DataCollect.Application": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Desktop.Defs": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Desktop.Initdata": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Desktop.JSUIString": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Desktop.PersonalUpdater": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Desktop.SessionData": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Desktop.Timeout": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Desktop.UIString": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Desktop.Upgrade": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Directory.Azure.SSO": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Directory.Domain": {
            "maxVersion": 3,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Directory.Domain.Conf": {
            "maxVersion": 3,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Directory.Domain.Schedule": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Directory.Domain.Trust": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Directory.LDAP": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Directory.LDAP.BaseDN": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Directory.LDAP.Login.Notify": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Directory.LDAP.Profile": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Directory.LDAP.Refresh": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Directory.LDAP.User": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Directory.OIDC.SSO": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Directory.SSO": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Directory.SSO.CAS": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Directory.SSO.IWA": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Directory.SSO.Profile": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Directory.SSO.SAML": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Directory.SSO.SAML.Metadata": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Directory.SSO.SAML.Status": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Directory.SSO.Setting": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Directory.SSO.Status": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Directory.SSO.utils": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Directory.WebSphere.SSO": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.DirectoryServiceCheck.Common": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.DirectoryServiceCheck.Debug": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.DirectoryServiceCheck.Domain": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.DirectoryServiceCheck.DomainJoin": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.DirectoryServiceCheck.DomainService": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.DirectoryServiceCheck.DomainValidation": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.DirectoryServiceCheck.LDAP": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.DirectoryServiceCheck.Progress": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.DisableAdmin": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.EW.Info": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.EventScheduler": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.EventScheduler.Root": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.ExternalDevice.Bluetooth": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.ExternalDevice.Bluetooth.Device": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.ExternalDevice.Bluetooth.Settings": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.ExternalDevice.DefaultPermission": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.ExternalDevice.Printer": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.ExternalDevice.Printer.BonjourSharing": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.ExternalDevice.Printer.Driver": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.ExternalDevice.Printer.Network": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.ExternalDevice.Printer.Network.Host": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.ExternalDevice.Printer.OAuth": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.ExternalDevice.Printer.USB": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.ExternalDevice.Storage.EUnit": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.ExternalDevice.Storage.Setting": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.ExternalDevice.Storage.USB": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.ExternalDevice.Storage.eSATA": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.ExternalDevice.UPS": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Factory.Config": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Factory.Manutild": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.File": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.File.Thumbnail": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.FileHandle": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.FileServ.AFP": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.FileServ.FTP": {
            "maxVersion": 3,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.FileServ.FTP.ChrootUser": {
            "maxVersion": 2,
            "minVersion": 2,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.FileServ.FTP.SFTP": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.FileServ.FTP.Security": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.FileServ.NFS": {
            "maxVersion": 3,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.FileServ.NFS.AdvancedSetting": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.FileServ.NFS.ConfBackup": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.FileServ.NFS.IDMap": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.FileServ.NFS.Kerberos": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.FileServ.NFS.SharePrivilege": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.FileServ.ReflinkCopy": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.FileServ.Rsync.Account": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.FileServ.SMB": {
            "maxVersion": 3,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.FileServ.SMB.ConfBackup": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.FileServ.SMB.Control": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.FileServ.SMB.MSDFS": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.FileServ.ServiceDiscovery": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.FileServ.ServiceDiscovery.WSTransfer": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Findhost": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Group": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Group.ExtraAdmin": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Group.Member": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Group.ValidLocalAdmin": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.GroupSettings": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Hardware.BeepControl": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Hardware.FanSpeed": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Hardware.Hibernation": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Hardware.LCM": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Hardware.Led.Brightness": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Hardware.MemoryLayout": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Hardware.NeedReboot": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Hardware.OOBManagement": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Hardware.PowerRecovery": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Hardware.PowerSchedule": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Hardware.RemoteFanStatus": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Hardware.SpectreMeltdown": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Hardware.VideoTranscoding": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Hardware.ZRAM": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Help": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.ISCSI.FCTarget": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.ISCSI.Host": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.ISCSI.LUN": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.ISCSI.Lunbkp": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.ISCSI.Node": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.ISCSI.Replication": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.ISCSI.Target": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.ISCSI.VMware": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.MediaIndexing": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.MediaIndexing.IndexFolder": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.MediaIndexing.MediaConverter": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.MediaIndexing.Scheduler": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.MediaIndexing.ThumbnailQuality": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.MyDSCenter": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.MyDSCenter.Account": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.MyDSCenter.Login": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.MyDSCenter.Logout": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.MyDSCenter.Purchase": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Network": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Network.Authentication": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Network.Authentication.Cert": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Network.Bond": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Network.Ethernet": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Network.Ethernet.External": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Network.IPv6": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Network.IPv6.Router": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Network.IPv6.Router.Prefix": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Network.Interface": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Network.MACClone": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Network.OVS": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Network.PPPoE": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Network.PPPoE.Relay": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Network.Proxy": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Network.Router.Gateway.List": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Network.Router.Static.Route": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Network.TrafficControl.RouterRules": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Network.TrafficControl.Rules": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Network.UPnPServer": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Network.VPN": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Network.VPN.L2TP": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Network.VPN.OpenVPN": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Network.VPN.OpenVPN.CA": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Network.VPN.OpenVPNWithConf": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Network.VPN.OpenVPNWithConf.Certs": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Network.VPN.PPTP": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Network.WOL": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.NormalUser": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.NormalUser.LoginNotify": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Notification.Advance.CustomizedData": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Notification.Advance.FilterSettings": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Notification.Advance.FilterSettings.Profile": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Notification.Advance.FilterSettings.Template": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Notification.Advance.Variables": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Notification.Advance.WarningPercentage": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Notification.CMS": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Notification.CMS.Conf": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Notification.Line": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Notification.Mail": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Notification.Mail.Auth": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Notification.Mail.Conf": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Notification.Mail.Oauth": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Notification.Mail.Profile.Conf": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Notification.Push": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Notification.Push.AuthToken": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Notification.Push.Conf": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Notification.Push.Mail": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Notification.Push.Mobile": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Notification.Push.Webhook.Provider": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Notification.SMS": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Notification.SMS.Conf": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Notification.SMS.Provider": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Notification.Sysnotify": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.OAuth.Scope": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.OAuth.Server": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.OTP": {
            "maxVersion": 3,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.OTP.Admin": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.OTP.EnforcePolicy": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.OTP.Ex": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.OTP.Mail": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Package": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Package.AutoUpgrade.Progress": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Package.Control": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Package.FakeIFrame": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Package.Feed": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Package.Info": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Package.Installation": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Package.Installation.Download": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Package.Legal.PreRelease": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Package.Log": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Package.MyDS": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Package.MyDS.Purchase": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Package.Progress": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Package.Screenshot": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Package.Screenshot.Server": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Package.Server": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Package.Setting": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Package.Setting.Update": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Package.Setting.Volume": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Package.Thumb": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Package.Thumb.Server": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Package.Uninstallation": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.PersonalNotification.Device": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.PersonalNotification.Event": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.PersonalNotification.Filter": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.PersonalNotification.Mobile": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.PersonalNotification.Settings": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.PersonalSettings": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.PhotoViewer": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Polling.Data": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.PortForwarding": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.PortForwarding.Compatibility": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.PortForwarding.RouterConf": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.PortForwarding.RouterInfo": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.PortForwarding.RouterList": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.PortForwarding.Rules": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.PortForwarding.Rules.Serv": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Promotion.Info": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Promotion.PreInstall": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.QuickConnect": {
            "maxVersion": 3,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.QuickConnect.Hostname": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.QuickConnect.Permission": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.QuickConnect.RegisterSite": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.QuickConnect.SNI": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.QuickConnect.Upnp": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.QuickStart.Info": {
            "maxVersion": 3,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.QuickStart.Install": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Quota": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.RecycleBin": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.RecycleBin.User": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Region.Language": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Region.NTP": {
            "maxVersion": 3,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Region.NTP.DateTimeFormat": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Region.NTP.Server": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Report": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Report.Analyzer": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Report.Analyzer.File": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Report.Analyzer.Share": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Report.Config": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Report.History": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Report.Redirect": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Report.Util": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.ResetAdmin": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.SNMP": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Security.AutoBlock": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Security.AutoBlock.Rules": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Security.DSM": {
            "maxVersion": 5,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Security.DSM.Embed": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Security.DSM.Proxy": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Security.DoS": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Security.Firewall": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Security.Firewall.Adapter": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Security.Firewall.Conf": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Security.Firewall.Geoip": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Security.Firewall.Profile": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Security.Firewall.Profile.Apply": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Security.Firewall.Rules": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Security.Firewall.Rules.Serv": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.SecurityScan.Conf": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.SecurityScan.Operation": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.SecurityScan.Status": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Service": {
            "maxVersion": 3,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Service.Conf": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Service.PortInfo": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Share": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Share.Crypto": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Share.Crypto.Key": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Share.CryptoFile": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Share.KeyManager.AutoKey": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Share.KeyManager.Key": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Share.KeyManager.MachineKey": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Share.KeyManager.Store": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Share.Migration": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Share.Migration.Task": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Share.Permission": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Share.PermissionReport": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Share.Snapshot": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Sharing": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Sharing.Initdata": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Sharing.Login": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Sharing.Session": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.SmartBlock": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.SmartBlock.Device": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.SmartBlock.Trusted": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.SmartBlock.Untrusted": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.SmartBlock.User": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Storage.Disk": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Storage.Disk.FWUpgrade": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Storage.Pool": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Storage.Volume": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Storage.iSCSILUN": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.SupportForm.Form": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.SupportForm.Log": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.SupportForm.Service": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Synohdpack": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.SyslogClient.FileTransfer": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.SyslogClient.Log": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.SyslogClient.PersonalActivity": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.SyslogClient.Setting.Notify": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.SyslogClient.Status": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.System": {
            "maxVersion": 3,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.System.Process": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.System.ProcessGroup": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.System.ResetButton": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.System.Status": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.System.SystemHealth": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.System.Utilization": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.TFTP": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.TaskScheduler": {
            "maxVersion": 4,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.TaskScheduler.Root": {
            "maxVersion": 4,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Terminal": {
            "maxVersion": 3,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Theme.AppPortalLogin": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Theme.Desktop": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Theme.FileSharingLogin": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Theme.Image": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Theme.Login": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.TrustDevice": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Tuned": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.UISearch": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Upgrade": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Upgrade.AutoUpgrade": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Upgrade.Cluster.Patch": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Upgrade.Cluster.Server": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Upgrade.Cluster.Server.Download": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Upgrade.Group": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Upgrade.Group.Download": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Upgrade.Group.Setting": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Upgrade.GroupInstall": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Upgrade.GroupInstall.Network": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Upgrade.JuniorModeData": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Upgrade.Patch": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Upgrade.PreCheck": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Upgrade.RemoteAction": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Upgrade.Server": {
            "maxVersion": 4,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Upgrade.Server.Download": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Upgrade.Setting": {
            "maxVersion": 4,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.User": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.User.Group": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.User.Home": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.User.PasswordConfirm": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.User.PasswordExpiry": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.User.PasswordMeter": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.User.PasswordPolicy": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.User.UsernamePolicy": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.UserSettings": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Virtualization.Host.Capability": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Web.DSM": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Web.DSM.External": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Web.Security.HTTPCompression": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Core.Web.Security.TLSProfile": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.DR.Node": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.DR.Node.Credential": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.DR.Node.Session": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.DSM.FindMe": {
            "maxVersion": 2,
            "minVersion": 2,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.DSM.Info": {
            "maxVersion": 2,
            "minVersion": 2,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.DSM.Network": {
            "maxVersion": 2,
            "minVersion": 2,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.DSM.PortEnable": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.DSM.PushNotification": {
            "maxVersion": 2,
            "minVersion": 2,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Default.API": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.DisasterRecovery.Log": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.DisasterRecovery.Retention": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.DownloadStation.BTSearch": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "DownloadStation/btsearch.cgi",
        },
        "SYNO.DownloadStation.Info": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "DownloadStation/info.cgi",
        },
        "SYNO.DownloadStation.RSS.Feed": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "DownloadStation/RSSfeed.cgi",
        },
        "SYNO.DownloadStation.RSS.Site": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "DownloadStation/RSSsite.cgi",
        },
        "SYNO.DownloadStation.Schedule": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "DownloadStation/schedule.cgi",
        },
        "SYNO.DownloadStation.Statistic": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "DownloadStation/statistic.cgi",
        },
        "SYNO.DownloadStation.Task": {
            "maxVersion": 3,
            "minVersion": 1,
            "path": "DownloadStation/task.cgi",
        },
        "SYNO.DownloadStation2.BTSearch": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.DownloadStation2.Captcha": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.DownloadStation2.Package.Info": {
            "maxVersion": 2,
            "minVersion": 2,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.DownloadStation2.Package.Module": {
            "maxVersion": 2,
            "minVersion": 2,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.DownloadStation2.Package.Service": {
            "maxVersion": 2,
            "minVersion": 2,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.DownloadStation2.RSS.Feed": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.DownloadStation2.RSS.Filter": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.DownloadStation2.RSS.Item": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.DownloadStation2.Settings.AutoExtraction": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.DownloadStation2.Settings.BT": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.DownloadStation2.Settings.BTSearch": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.DownloadStation2.Settings.Emule": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.DownloadStation2.Settings.Emule.Location": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.DownloadStation2.Settings.FileHosting": {
            "maxVersion": 2,
            "minVersion": 2,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.DownloadStation2.Settings.FtpHttp": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.DownloadStation2.Settings.Global": {
            "maxVersion": 2,
            "minVersion": 2,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.DownloadStation2.Settings.Location": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.DownloadStation2.Settings.Nzb": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.DownloadStation2.Settings.Rss": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.DownloadStation2.Settings.Scheduler": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.DownloadStation2.Task": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.DownloadStation2.Task.BT": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.DownloadStation2.Task.BT.File": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.DownloadStation2.Task.BT.Peer": {
            "maxVersion": 2,
            "minVersion": 2,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.DownloadStation2.Task.BT.Tracker": {
            "maxVersion": 2,
            "minVersion": 2,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.DownloadStation2.Task.Complete": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.DownloadStation2.Task.List": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.DownloadStation2.Task.List.Polling": {
            "maxVersion": 2,
            "minVersion": 2,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.DownloadStation2.Task.NZB.File": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.DownloadStation2.Task.NZB.Log": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.DownloadStation2.Task.Source": {
            "maxVersion": 2,
            "minVersion": 2,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.DownloadStation2.Task.Statistic": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.DownloadStation2.Task.eMule": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.DownloadStation2.Thumbnail": {
            "maxVersion": 2,
            "minVersion": 2,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.DownloadStation2.eMule.Search": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.DownloadStation2.eMule.Server": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Entry.Request": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Entry.Request.Polling": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Entry.SocketIo": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.FileStation.BackgroundTask": {
            "maxVersion": 3,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.FileStation.CheckExist": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.FileStation.CheckPermission": {
            "maxVersion": 3,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.FileStation.Compress": {
            "maxVersion": 3,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.FileStation.CopyMove": {
            "maxVersion": 3,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.FileStation.CreateFolder": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.FileStation.Delete": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.FileStation.DirSize": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.FileStation.Download": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.FileStation.External.GoogleDrive": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.FileStation.Extract": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.FileStation.Favorite": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.FileStation.FormUpload": {
            "maxVersion": 2,
            "minVersion": 2,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.FileStation.Info": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.FileStation.List": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.FileStation.MD5": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.FileStation.Mount": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.FileStation.Mount.List": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.FileStation.Notify": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.FileStation.PhotoUpload": {
            "maxVersion": 3,
            "minVersion": 2,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.FileStation.Property": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.FileStation.Property.ACLOwner": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.FileStation.Property.CompressSize": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.FileStation.Property.Mtime": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.FileStation.Rename": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.FileStation.Search": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.FileStation.Search.History": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.FileStation.Settings": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.FileStation.Sharing": {
            "maxVersion": 3,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.FileStation.Sharing.Download": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.FileStation.Snapshot": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.FileStation.Thumb": {
            "maxVersion": 3,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.FileStation.Timeout": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.FileStation.UIString": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.FileStation.Upload": {
            "maxVersion": 3,
            "minVersion": 2,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.FileStation.UserGrp": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.FileStation.VFS.Connection": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.FileStation.VFS.File": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.FileStation.VFS.GDrive": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.FileStation.VFS.Profile": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.FileStation.VFS.Protocol": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.FileStation.VFS.User": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.FileStation.VirtualFolder": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.FileStation.Worm": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.FileStation.Worm.Lock": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Finder.AppIndexing.Search": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Finder.Bookmark": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Finder.Elastic.SearchHistory": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Finder.Elastic.Spotlight": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Finder.Elastic.Term": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Finder.File": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Finder.File.Cover": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Finder.File.Thumbnail": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Finder.FileIndexing.Folder": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Finder.FileIndexing.Highlight": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Finder.FileIndexing.Indicate": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Finder.FileIndexing.Search": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Finder.FileIndexing.Status": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Finder.FileIndexing.Term": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Finder.Preference": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Finder.Settings": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Finder.UserGrp": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.FolderSharing.Download": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.FolderSharing.List": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.FolderSharing.Thumb": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Foto.BackgroundTask.File": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Foto.BackgroundTask.Info": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Foto.Browse.Album": {
            "maxVersion": 5,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Foto.Browse.Category": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Foto.Browse.Concept": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Foto.Browse.ConditionAlbum": {
            "maxVersion": 3,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Foto.Browse.Diff": {
            "maxVersion": 5,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Foto.Browse.Folder": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Foto.Browse.GeneralTag": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Foto.Browse.Geocoding": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Foto.Browse.Item": {
            "maxVersion": 5,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Foto.Browse.NormalAlbum": {
            "maxVersion": 3,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Foto.Browse.Person": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Foto.Browse.RecentlyAdded": {
            "maxVersion": 5,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Foto.Browse.Timeline": {
            "maxVersion": 5,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Foto.Browse.Unit": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Foto.Development.Admin": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Foto.Download": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Foto.Favorite": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Foto.Index": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Foto.Migration": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Foto.Notification": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Foto.PhotoRequest": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Foto.PublicSharing": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Foto.Search.Filter": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Foto.Search.Search": {
            "maxVersion": 6,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Foto.Setting.Admin": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Foto.Setting.Guest": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Foto.Setting.MobileCompatibility": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Foto.Setting.TeamSpace": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Foto.Setting.User": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Foto.Setting.Wizard": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Foto.Sharing.Misc": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Foto.Sharing.Passphrase": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Foto.Streaming": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Foto.Thumbnail": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Foto.Udc": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Foto.Upload.ConvertedFile": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Foto.Upload.Item": {
            "maxVersion": 5,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Foto.Upload.PhotoRequestItem": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Foto.UserInfo": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.FotoTeam.BackgroundTask.File": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.FotoTeam.Browse.Concept": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.FotoTeam.Browse.Diff": {
            "maxVersion": 5,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.FotoTeam.Browse.Folder": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.FotoTeam.Browse.GeneralTag": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.FotoTeam.Browse.Geocoding": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.FotoTeam.Browse.Item": {
            "maxVersion": 5,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.FotoTeam.Browse.Person": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.FotoTeam.Browse.RecentlyAdded": {
            "maxVersion": 5,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.FotoTeam.Browse.Timeline": {
            "maxVersion": 5,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.FotoTeam.Browse.Unit": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.FotoTeam.Download": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.FotoTeam.Index": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.FotoTeam.Search.Filter": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.FotoTeam.Search.Search": {
            "maxVersion": 6,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.FotoTeam.Sharing.FolderBatchPermission": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.FotoTeam.Sharing.FolderPermission": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.FotoTeam.Sharing.Passphrase": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.FotoTeam.Streaming": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.FotoTeam.Thumbnail": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.FotoTeam.Upload.ConvertedFile": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.FotoTeam.Upload.Item": {
            "maxVersion": 5,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.HCI.Cluster": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.HCI.Guest": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.HCI.Host": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.HCI.Utils": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.License.HA": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.LogCenter.Client": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.LogCenter.Client.CA": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.LogCenter.History": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.LogCenter.Log": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.LogCenter.RecvRule": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.LogCenter.Setting.Storage": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Lunbackup": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.MailClient.Attachment": {
            "maxVersion": 8,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.MailClient.CMSCertificate": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.MailClient.Draft": {
            "maxVersion": 6,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.MailClient.Filter": {
            "maxVersion": 3,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.MailClient.Info": {
            "maxVersion": 5,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.MailClient.Label": {
            "maxVersion": 3,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.MailClient.MailMerge": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.MailClient.MailTemplate": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.MailClient.MailTrack": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.MailClient.Mailbox": {
            "maxVersion": 7,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.MailClient.Message": {
            "maxVersion": 10,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.MailClient.PGPKey": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.MailClient.SearchHistory": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.MailClient.Setting": {
            "maxVersion": 3,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.MailClient.Setting.CustomAutoReply": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.MailClient.Setting.CustomLogo": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.MailClient.Setting.Encryption": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.MailClient.Setting.ForwardReply": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.MailClient.Setting.General": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.MailClient.Setting.Lab": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.MailClient.Setting.MailTrack": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.MailClient.Setting.ManualConfig": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.MailClient.Setting.Notification": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.MailClient.Setting.PGP": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.MailClient.Setting.POP3": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.MailClient.Setting.PriorityMailbox": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.MailClient.Setting.SMTP": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.MailClient.Setting.SharingLink": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.MailClient.Signature": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.MailClient.SpamRule": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.MailClient.Sticker": {
            "maxVersion": 3,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.MailClient.Theme": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.MailClient.Thread": {
            "maxVersion": 10,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.MailClient.UserDataCollect": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.MailClient.UserPreference": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.MailPlusServer.Account.Detail": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.MailPlusServer.Account.Maildir": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.MailPlusServer.Account.Quota": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.MailPlusServer.Alias": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.MailPlusServer.Audit.AdminLog": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.MailPlusServer.Audit.DovecotLog": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.MailPlusServer.Audit.SearchTask": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.MailPlusServer.Audit.SearchTaskResult": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.MailPlusServer.Audit.TransactionLog": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.MailPlusServer.Client": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.MailPlusServer.Cluster": {
            "maxVersion": 3,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.MailPlusServer.CreateWizard": {
            "maxVersion": 7,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.MailPlusServer.Delegation": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.MailPlusServer.Diagnosis": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.MailPlusServer.Disclaimer": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.MailPlusServer.Domain": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.MailPlusServer.Domain.AdditionalDomain": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.MailPlusServer.Domain.BCC": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.MailPlusServer.Domain.Group": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.MailPlusServer.Domain.Settings": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.MailPlusServer.Domain.User": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.MailPlusServer.FullTextSearch": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.MailPlusServer.IMAP_POP3": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.MailPlusServer.IMAP_POP3_ADVANCED": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.MailPlusServer.License": {
            "maxVersion": 3,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.MailPlusServer.License.BitDefender": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.MailPlusServer.License.Payment": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.MailPlusServer.Log": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.MailPlusServer.Log.Mail": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.MailPlusServer.Log.Security": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.MailPlusServer.MailImportExport": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.MailPlusServer.MailPlus": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.MailPlusServer.Migration": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.MailPlusServer.Normal.Util": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.MailPlusServer.Personal.AutoReply": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.MailPlusServer.Personal.Forward": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.MailPlusServer.Personal.ForwardReply": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.MailPlusServer.Queue": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.MailPlusServer.RemoteMigrate": {
            "maxVersion": 5,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.MailPlusServer.Report": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.MailPlusServer.SMTP": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.MailPlusServer.SMTP.Delivery": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.MailPlusServer.SMTP.General": {
            "maxVersion": 3,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.MailPlusServer.SMTP.RelayControl": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.MailPlusServer.SMTP.Security": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.MailPlusServer.Security": {
            "maxVersion": 4,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.MailPlusServer.Security.AttachmentFilter": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.MailPlusServer.Security.BlackwhiteList": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.MailPlusServer.Security.DailyQuota": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.MailPlusServer.Security.Dane": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.MailPlusServer.Security.DkimTrustSender": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.MailPlusServer.Security.Greylist": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.MailPlusServer.Security.MCP": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.MailPlusServer.Security.MCPQuarantine": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.MailPlusServer.Security.PostScreen": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.MailPlusServer.Security.VirusQuarantine": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.MailPlusServer.SecurityDashboard": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.MailPlusServer.ServerList": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.MailPlusServer.Service.SMTP": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.MailPlusServer.Spam.ReportedHam": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.MailPlusServer.Spam.ReportedSpam": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.MailPlusServer.Spam.SpamAssassin": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.MailPlusServer.Statistic": {
            "maxVersion": 4,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.MailPlusServer.UserGroupPolicy": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.MailPlusServer.Util": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.MailPlusServer.Version": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.OAUTH.Client": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.OAUTH.Common": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.OAUTH.Log": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.OAUTH.Token": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Package": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.PersonMailAccount": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.PersonMailAccount.Contacts": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.PersonMailAccount.Mail": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.PersonMailAccount.Mail.Oauth": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Personal.Application.Info": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Personal.MailAccount": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Personal.MailAccount.Contacts": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Personal.MailAccount.Mail": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Personal.Notification.Conf": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Personal.Notification.Device": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Personal.Notification.Event": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Personal.Notification.Filter": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Personal.Notification.GDPR": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Personal.Notification.Identifier": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Personal.Notification.Mobile": {
            "maxVersion": 3,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Personal.Notification.Settings": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Personal.Notification.Token": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Personal.Notification.VapidPublicKey": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Personal.Profile": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Personal.Profile.Photo": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Remote.Credential": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Remote.Credential.Challenge": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Remote.Credential.Info": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Remote.Credential.Verifier": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.ResourceMonitor.EventRule": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.ResourceMonitor.Log": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.ResourceMonitor.Setting": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.S2S.Client": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.S2S.Client.Job": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.S2S.Server": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.S2S.Server.Pair": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.SAS.APIRunner": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.SAS.APIRunner.Chatbot": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.SAS.Encryption": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.SAS.Group": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.SAS.Group.Members": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.SAS.Guest": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.SDS.Backup.Client.Common.Log": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.SDS.Backup.Client.Common.Statistic": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.SDS.Backup.Client.Common.Target": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.SDS.Backup.Client.Common.Version": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.SDS.Backup.Client.Explore.File": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.SDS.Backup.Client.Explore.Folder": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.SDS.Backup.Client.Explore.Job": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.SDS.Backup.Client.Explore.Target": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.SDS.Backup.Client.Explore.Version": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.SDS.Backup.Client.Fuse.Target": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.SDS.Backup.Server.Common.Log": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.SDS.Backup.Server.Common.Statistic": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.SDS.Backup.Server.Common.Target": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.SDS.Backup.Server.Common.Version": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.SDS.Backup.Server.Explore.File": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.SDS.Backup.Server.Explore.Folder": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.SDS.Backup.Server.Explore.Job": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.SDS.Backup.Server.Explore.Target": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.SDS.Backup.Server.Explore.Version": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.SDS.Backup.Server.Fuse.Target": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.SecureSignIn.AMFA.Mail.Ex": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.SecureSignIn.AMFA.Policy": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.SecureSignIn.AMFA.SuggestConn": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.SecureSignIn.Authenticator": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.SecureSignIn.Authenticator.Ex": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.SecureSignIn.Authenticator.Info": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.SecureSignIn.Authenticator.Registration": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.SecureSignIn.Authenticator.Registration.Ex": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.SecureSignIn.Authenticator.Request": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.SecureSignIn.Authenticator.Verdict": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.SecureSignIn.Fido.Manage": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.SecureSignIn.Fido.Manage.Ex": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.SecureSignIn.Fido.Register": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.SecureSignIn.Fido.Register.Ex": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.SecureSignIn.Method": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.SecureSignIn.Method.Admin": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.SecureSignIn.Method.Ex": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.SecureSignIn.Package": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.SecureSignIn.Package.Ex": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.SecureSignIn.Package.Request": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.SecurityAdvisor.Conf": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.SecurityAdvisor.Conf.Checklist": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.SecurityAdvisor.Conf.Checklist.Alert": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.SecurityAdvisor.Conf.Location": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.SecurityAdvisor.LoginActivity": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.SecurityAdvisor.LoginActivity.User": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.SecurityAdvisor.Report": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.SecurityAdvisor.Report.HTML": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.ShareLink.Action": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.ShareLink.Download": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.ShareLink.Manage": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Snap.Usage.Share": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Storage.CGI.BtrfsDedupe": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Storage.CGI.Cache.Protection": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Storage.CGI.Check": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Storage.CGI.DetectedPool": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Storage.CGI.DualEnclosure": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Storage.CGI.Enclosure": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Storage.CGI.EncryptionKeyVault": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Storage.CGI.EncryptionKeyVault.UnlockMode": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Storage.CGI.Flashcache": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Storage.CGI.HddMan": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Storage.CGI.KMIP": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Storage.CGI.Pool": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Storage.CGI.Scrubbing": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Storage.CGI.Smart": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Storage.CGI.Smart.Scheduler": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Storage.CGI.Spare": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Storage.CGI.Spare.Conf": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Storage.CGI.Storage": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Storage.CGI.TaipeiEnclosure": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Storage.CGI.Volume": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Storage.CGI.Volume.Installer": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Storage.CGI.Volume.OfflineOp": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.SupportService.Setting": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.SynologyDrive": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.SynologyDrive.Activation": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.SynologyDrive.AdvanceSharing": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.SynologyDrive.AdvanceSharing.Public": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.SynologyDrive.AppIntegration": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.SynologyDrive.Authentication": {
            "maxVersion": 3,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.SynologyDrive.Config": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.SynologyDrive.Connection": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.SynologyDrive.DBUsage": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.SynologyDrive.DSM": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.SynologyDrive.Dashboard": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.SynologyDrive.Files": {
            "maxVersion": 10,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.SynologyDrive.HybridShare.Privilege": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.SynologyDrive.Index": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.SynologyDrive.Info": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.SynologyDrive.KeyManagement": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.SynologyDrive.Labels": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.SynologyDrive.Log": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.SynologyDrive.Metrics": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.SynologyDrive.Metrics.Token": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.SynologyDrive.Migration": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.SynologyDrive.Migration.UserHome": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.SynologyDrive.Mobile.Notification": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.SynologyDrive.Node": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.SynologyDrive.Node.Delete": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.SynologyDrive.Node.Download": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.SynologyDrive.Node.Restore": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.SynologyDrive.Notifications": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.SynologyDrive.Office": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.SynologyDrive.Photos": {
            "maxVersion": 3,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.SynologyDrive.Privilege": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.SynologyDrive.Profiles": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.SynologyDrive.Revisions": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.SynologyDrive.SCIM.Photo": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.SynologyDrive.SCIM.User": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.SynologyDrive.Services.DocumentViewer": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.SynologyDrive.Services.SynologyChat": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.SynologyDrive.Services.VideoStation": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.SynologyDrive.Settings": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.SynologyDrive.Shard": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.SynologyDrive.Share": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.SynologyDrive.Share.Priv": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.SynologyDrive.Sharing": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.SynologyDrive.Sharing.Report": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.SynologyDrive.Statistics": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.SynologyDrive.String": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.SynologyDrive.Tasks": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.SynologyDrive.TeamFolders": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.SynologyDrive.Trash": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.SynologyDrive.Users": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.SynologyDrive.Webhooks": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.SynologyDriveShareSync.Config": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.SynologyDriveShareSync.Connection": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.SynologyDriveShareSync.Session": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.SynologyDriveShareSync.Session.Set": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.TextEditor": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.TextEditor.Preference": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Utils": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.VMMDR.Btrfs.Replica": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.VMMDR.Credential": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.VMMDR.Plan": {
            "maxVersion": 3,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.VMMDR.Plan.DRSite": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.VMMDR.Plan.MainSite": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.VMMDR.Plan.Site": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.VMMDR.Topology": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.VideoPlayer.Subtitle": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.VideoPlayer.SynologyDrive.Subtitle": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Virtualization.API.Guest": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Virtualization.API.Guest.Action": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Virtualization.API.Guest.Image": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Virtualization.API.Host": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Virtualization.API.Network": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Virtualization.API.Storage": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Virtualization.API.Task.Info": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Virtualization.Cluster": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Virtualization.Guest": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Virtualization.Guest.Action": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Virtualization.Guest.Image": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Virtualization.Guest.P2V": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Virtualization.GuestProtect.Plan": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Virtualization.GuestProtect.Policy": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Virtualization.GuestProtect.Snap": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Virtualization.HA": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Virtualization.HA.Setting": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Virtualization.Host": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Virtualization.License": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Virtualization.License.Pro": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Virtualization.License.VDSM": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Virtualization.Log": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Virtualization.Network": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Virtualization.Network.SRIOV": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Virtualization.Package": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Virtualization.Repo": {
            "maxVersion": 2,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Virtualization.Setting.General": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Virtualization.Setting.Notify": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Virtualization.Setting.UI": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Virtualization.Sharing.VNC": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Virtualization.User": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.Virtualization.Utils": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.WebDAV.CalDAV.Calendar": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.WebDAV.Common": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.WebRTC.Proxy": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.WebRTC.Proxy.Sharing": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.WebStation.Backup": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.WebStation.Default": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.WebStation.Docker": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.WebStation.ErrorPage": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.WebStation.HTTP.VHost": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.WebStation.PHP": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.WebStation.PHP.Profile": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.WebStation.Package": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.WebStation.Python": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.WebStation.Python.Profile": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.WebStation.ScriptLanguage": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.WebStation.ScriptLanguage.Utils": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.WebStation.Shortcut": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.WebStation.Status": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.WebStation.Task": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.WebStation.WebService.Portal": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.WebStation.WebService.Portal.Log": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
        "SYNO.WebStation.WebService.Service": {
            "maxVersion": 1,
            "minVersion": 1,
            "path": "entry.cgi",
            "requestFormat": "JSON",
        },
    },
    "success": True,
}
